split_async

Function split_async 

pub async fn split_async(
    tar_stream: impl AsyncRead + Unpin,
    writer: &mut SplitStreamWriter<impl FsVerityHashValue>,
) -> Result<()>
Asynchronously splits a tar archive into a composefs split stream.

Similar to split() but processes the tar stream asynchronously. Files larger than INLINE_CONTENT_MAX are stored externally in the object store, while smaller files and metadata are stored inline in the split stream.

Returns an error if the tar stream is malformed or if writing to the split stream fails.